@@ -394,7 +394,7 @@ static u8 maybe_xsrf(u8* token) {
   static u8 tm_prefix[8];
 
   if (!tm_prefix[0])
-    sprintf((char*)tm_prefix, "%lu", time(0) / 100000);
+    sprintf((char*)tm_prefix, "%lu", (long int)(time(0) / 100000));
 
   /* Unix time is not a valid token. */
 
@@ -470,7 +470,7 @@ static void collect_form_data(struct http_request* req,
       }
 
       if (ISTAG(cur_str, "input") || ISTAG(cur_str, "textarea") ||
-          ISTAG(cur_str, "select")) {
+          ISTAG(cur_str, "select") || ISTAG(cur_str, "button")) {
 
         u8 *tag_name, *tag_value, *tag_type, *clean_name = NULL,
            *clean_value = NULL;
@@ -699,7 +699,8 @@ void scrape_response(struct http_request* req, struct http_response* res) {
         FIND_AND_MOVE(dirty_url, cur_str, "src=");
 
       } else if (ISTAG(cur_str, "object") || ISTAG(cur_str, "embed") ||
-               ISTAG(cur_str, "applet") || ISTAG(cur_str, "iframe")) {
+               ISTAG(cur_str, "applet") || ISTAG(cur_str, "iframe") ||
+               ISTAG(cur_str, "frame")) {
 
         link_type = 3;
         FIND_AND_MOVE(dirty_url, cur_str, "src=");
